@@ -1,4 +1,5 @@
 from . import _LOGGER
+import enum
 
 from .devices import _WiserDeviceCollection
 from .helpers import _WiserTemperatureFunctions as tf
@@ -9,126 +10,24 @@ from .const import (
     TEMP_MINIMUM,
     TEMP_MAXIMUM,
     TEMP_OFF,
+    TEXT_AUTO,
     TEXT_MANUAL,
     TEXT_OFF,
     TEXT_ON,
     TEXT_UNKNOWN,
-    WiserHeatingModeEnum,
     WISERROOM
 )
 
+class WiserHeatingModeEnum(enum.Enum):
+    off = TEXT_OFF
+    auto = TEXT_AUTO
+    manual = TEXT_MANUAL
+
+
 from datetime import datetime, timezone
 import inspect
 
 
-class _WiserRoomCollection(object):
-    """Class holding all wiser room objects"""
-
-    def __init__(
-        self, wiser_rest_controller: _WiserRestController, room_data: dict,
-        schedules: _WiserScheduleCollection, devices: _WiserDeviceCollection
-    ):
-
-        self._wiser_rest_controller = wiser_rest_controller
-        self._room_data = room_data
-        self._schedules = schedules.all
-        self._devices = devices
-        self._rooms = []
-
-        self._build()
-
-    def _build(self):
-        # Add room objects
-        #TODO: Make list of device id and also list of iTRVs, Roomstats and Smartplugs
-        for room in self._room_data:
-            schedule = [
-                schedule
-                for schedule in self._schedules
-                if schedule.id == room.get("ScheduleId")
-            ]
-            devices = [
-                device
-                for device in self._devices.all
-                if (
-                    device.id in room.get("SmartValveIds", ["-1"])
-                    or device.id == room.get("RoomStatId", "-1")
-                    or device.id
-                    in [
-                        smartplug.id
-                        for smartplug in self._devices._smartplugs_collection.all
-                        if smartplug.room_id == room.get("id", 0)
-                    ]
-                )
-            ]
-            self._rooms.append(
-                _WiserRoom(
-                    self._wiser_rest_controller,
-                    room,
-                    schedule[0] if len(schedule) > 0 else None,
-                    devices,
-                )
-            )
-
-
-    @property
-    def all(self):
-        return self._rooms
-
-    @property
-    def count(self) -> int:
-        return len(self._rooms)
-
-    def add(self, name):
-        # call domain/room with post and name param
-        raise NotImplemented
-
-    def delete(self, id: int):
-        # call room/id with delete
-        raise NotImplemented
-
-    def get_by_id(self, id: int):
-        """
-        Gets a room object for the room by id of room
-        param id: the id of the room
-        return: _WiserRoom object
-        """
-        try:
-            return [room for room in self._rooms if room.id == id][0]
-        except IndexError:
-            return None
-
-    def get_by_name(self, name: str):
-        """
-        Gets a room object for the room by name of room
-        param name: the name of the room
-        return: _WiserRoom object
-        """
-        try:
-            return [room for room in self._rooms if room.name.lower() == name.lower()][0]
-        except IndexError:
-            return None
-
-    def get_by_schedule_id(self, schedule_id: int):
-        """
-        Gets a room object for the room a schedule id belongs to
-        param schedule_id: the id of the schedule
-        return: _WiserRoom object
-        """
-        return [room for room in self._rooms if room.schedule_id == id][0]
-
-    def get_by_device_id(self, device_id: int):
-        """
-        Gets a room object for the room a device id belongs to
-        param device_id: the id of the device
-        return: _WiserRoom object
-        """
-        for room in self._rooms:
-            for device in room.devices:
-                if device.id == device_id:
-                    return room
-        return None
-
-    
 class _WiserRoom(object):
     """Class representing a Wiser Room entity"""
 
@@ -144,12 +43,12 @@ class _WiserRoom(object):
         self._name = room.get("Name")
         self._window_detection_active = room.get("WindowDetectionActive", TEXT_UNKNOWN)
 
-    def _effective_heating_mode(self, mode: str, temp: float) -> WiserHeatingModeEnum:
-        if mode == WiserHeatingModeEnum.manual.value and temp == TEMP_OFF:
-            return WiserHeatingModeEnum.off
-        elif mode == WiserHeatingModeEnum.manual.value:
-            return WiserHeatingModeEnum.manual
-        return WiserHeatingModeEnum.auto
+    def _effective_heating_mode(self, mode: str, temp: float) -> str:
+        if mode.casefold() == TEXT_MANUAL.casefold() and temp == TEMP_OFF:
+            return TEXT_OFF
+        elif mode.casefold() == TEXT_MANUAL.casefold():
+            return TEXT_MANUAL
+        return TEXT_AUTO
 
     def _send_command(self, cmd: dict):
         """
@@ -165,12 +64,20 @@ class _WiserRoom(object):
         return result
 
     @property
-    def away_mode_suppressed(self):
+    def available_modes(self) -> str:
+        """Get available heating modes"""
+        return [mode.value for mode in WiserHeatingModeEnum]
+
+    @property
+    def away_mode_suppressed(self) -> str:
+        """Get if away mode is suppressed for room"""
         return self._data.get("AwayModeSuppressed", TEXT_UNKNOWN)
 
     @property
-    def boost_end_time(self) -> datetime:
+    def boost_end_time(self) -> datetime | None:
         """Get boost end timestamp"""
+        if self._data.get("OverrideTimeoutUnixTime", 0) == 0:
+            return None
         return datetime.fromtimestamp(self._data.get("OverrideTimeoutUnixTime", 0))
 
     @property
@@ -192,7 +99,7 @@ class _WiserRoom(object):
         return tf._from_wiser_temp(self._data.get("CalculatedTemperature", TEMP_MINIMUM))
 
     @property
-    def current_humidity(self):
+    def current_humidity(self) -> int | None:
         """Get current humidity of the room if room has a roomstat"""
         for device in self.devices:
             if hasattr(device, "current_humidity"):
@@ -200,12 +107,12 @@ class _WiserRoom(object):
         return None
 
     @property
-    def devices(self):
+    def devices(self) -> list:
         """Get devices associated with the room"""
         return self._devices
 
     @property
-    def heating_rate(self):
+    def heating_rate(self) -> str:
         """Get room heating rate"""
         return self._data.get("HeatingRate", TEXT_UNKNOWN)
 
@@ -219,7 +126,7 @@ class _WiserRoom(object):
         """Get if the room temperature is currently set by away mode"""
         return (
             True
-            if "Away" in self._data.get("SetpointOrigin", self._data.get("SetPointOrigin",TEXT_UNKNOWN))
+            if "Away" in self._data.get("SetpointOrigin", self._data.get("SetPointOrigin", TEXT_UNKNOWN))
             else False
         )
 
@@ -254,24 +161,27 @@ class _WiserRoom(object):
         return tf._from_wiser_temp(self._data.get("ManualSetPoint", TEMP_MINIMUM))
 
     @property
-    def mode(self) -> WiserHeatingModeEnum:
+    def mode(self) -> str:
         """Get or set current mode for the room (Off, Manual, Auto)"""
-        return self._mode
+        return WiserHeatingModeEnum[self._mode.lower()].value
 
     @mode.setter
-    def mode(self, mode: WiserHeatingModeEnum):
-        if mode == WiserHeatingModeEnum.off:
+    def mode(self, mode: str):
+        if mode.casefold() == WiserHeatingModeEnum.off.value.casefold():
             self.set_manual_temperature(TEMP_OFF)
-        elif mode == WiserHeatingModeEnum.manual:
-            if self._send_command({"Mode": TEXT_MANUAL}):
+        elif mode.casefold() == WiserHeatingModeEnum.manual.value.casefold():
+            if self._send_command({"Mode": WiserHeatingModeEnum.manual.value}):
                 if self.current_target_temperature == TEMP_OFF:
                     self.set_target_temperature(self.scheduled_target_temperature)
-        elif mode == WiserHeatingModeEnum.auto:
+        elif mode.casefold() == WiserHeatingModeEnum.auto.value.casefold():
             if self.is_override:
                 self.cancel_overrides()
             self._send_command({"Mode": WiserHeatingModeEnum.auto.value})
-            
-        self._mode = mode
+        else:
+            raise ValueError(
+                f"{mode} is not a valid Heating mode.  Valid modes are {self.available_modes}"
+            )
+        self._mode = WiserHeatingModeEnum[mode.lower()].value
 
     @property
     def name(self) -> str:
@@ -299,7 +209,7 @@ class _WiserRoom(object):
         return self._data.get("PercentageDemand", 0)
 
     @property
-    def schedule(self):
+    def schedule(self) -> _WiserSchedule:
         """Get the schedule for the room"""
         return self._schedule
 
@@ -363,7 +273,7 @@ class _WiserRoom(object):
         if self.is_boosted:
             return self.cancel_overrides()
         else:
-            return False
+            return True
 
     def set_target_temperature(self, temp: float) -> bool:
         """
@@ -396,28 +306,137 @@ class _WiserRoom(object):
             }
         )
 
-    def set_manual_temperature(self, temp: float):
+    def set_manual_temperature(self, temp: float) -> bool:
         """
         Set the mode to manual with target temperature for the room
         param temp: the temperature to set in C
         return: boolean
         """
-        if self.mode != WiserHeatingModeEnum.manual:
-            self.mode = WiserHeatingModeEnum.manual
+        if self.mode != WiserHeatingModeEnum.manual.value:
+            self.mode = WiserHeatingModeEnum.manual.value
         return self.set_target_temperature(temp)
 
-    def schedule_advance(self):
+    def schedule_advance(self) -> bool:
         """
         Advance room schedule to the next scheduled time and temperature setting
         return: boolean
         """
         return self.set_target_temperature(
-            tf._from_wiser_temp(self.schedule.next_entry.setting)
+            tf._from_wiser_temp(self.schedule.next.setting)
         )
 
-    def cancel_overrides(self):
+    def cancel_overrides(self) -> bool:
         """
         Cancel all overrides and set room schedule to the current temperature setting for the mode
         return: boolean
         """
-        return self._send_command({"RequestOverride": {"Type": "None"}})
\ No newline at end of file
+        return self._send_command({"RequestOverride": {"Type": "None"}})
+
+
+class _WiserRoomCollection(object):
+    """Class holding all wiser room objects"""
+
+    def __init__(
+        self, wiser_rest_controller: _WiserRestController, room_data: dict,
+        schedules: _WiserScheduleCollection, devices: _WiserDeviceCollection
+    ):
+
+        self._wiser_rest_controller = wiser_rest_controller
+        self._room_data = room_data
+        self._schedules = schedules.all
+        self._devices = devices
+        self._rooms = []
+
+        self._build()
+
+    def _build(self):
+        # Add room objects
+        for room in self._room_data:
+            schedule = [
+                schedule
+                for schedule in self._schedules
+                if schedule.id == room.get("ScheduleId")
+            ]
+            devices = [
+                device
+                for device in self._devices.all
+                if (
+                    device.id in room.get("SmartValveIds", ["-1"])
+                    or device.id == room.get("RoomStatId", "-1")
+                    or device.id
+                    in [
+                        smartplug.id
+                        for smartplug in self._devices._smartplugs_collection.all
+                        if smartplug.room_id == room.get("id", 0)
+                    ]
+                )
+            ]
+            self._rooms.append(
+                _WiserRoom(
+                    self._wiser_rest_controller,
+                    room,
+                    schedule[0] if len(schedule) > 0 else None,
+                    devices,
+                )
+            )
+
+
+    @property
+    def all(self) -> list:
+        return self._rooms
+
+    @property
+    def count(self) -> int:
+        return len(self._rooms)
+
+    def add(self, name):
+        # call domain/room with post and name param
+        raise NotImplemented
+
+    def delete(self, id: int):
+        # call room/id with delete
+        raise NotImplemented
+
+    def get_by_id(self, id: int) -> _WiserRoom:
+        """
+        Gets a room object for the room by id of room
+        param id: the id of the room
+        return: _WiserRoom object
+        """
+        try:
+            return [room for room in self._rooms if room.id == id][0]
+        except IndexError:
+            return None
+
+    def get_by_name(self, name: str) -> _WiserRoom:
+        """
+        Gets a room object for the room by name of room
+        param name: the name of the room
+        return: _WiserRoom object
+        """
+        try:
+            return [room for room in self._rooms if room.name.lower() == name.lower()][0]
+        except IndexError:
+            return None
+
+    def get_by_schedule_id(self, schedule_id: int) -> _WiserRoom:
+        """
+        Gets a room object for the room a schedule id belongs to
+        param schedule_id: the id of the schedule
+        return: _WiserRoom object
+        """
+        return [room for room in self._rooms if room.schedule_id == schedule_id][0]
+
+    def get_by_device_id(self, device_id: int) -> _WiserRoom:
+        """
+        Gets a room object for the room a device id belongs to
+        param device_id: the id of the device
+        return: _WiserRoom object
+        """
+        for room in self._rooms:
+            for device in room.devices:
+                if device.id == device_id:
+                    return room
+        return None
+
+    
\ No newline at end of file
