@@ -12,53 +12,6 @@ from .const import (SPECIAL_DAYS, TEMP_MINIMUM, TEMP_OFF, TEXT_DEGREESC,
 from .helpers import _WiserTemperatureFunctions as tf
 from .rest_controller import _WiserRestController
 
-class _WiserScheduleCollection(object):
-    """Class holding all wiser schedule objects"""
-
-    def __init__(self, wiser_rest_controller, schedule_data: dict):
-        self._wiser_rest_controller = wiser_rest_controller
-        self._schedules = []
-
-        self._build(schedule_data)
-
-    def _build(self, schedule_data):
-        for schedule_type in schedule_data:
-            for schedule in schedule_data.get(schedule_type):
-                self._schedules.append(_WiserSchedule(self._wiser_rest_controller, schedule_type, schedule))
-
-    @property
-    def all(self):
-        return self._schedules
-
-    @property
-    def count(self) -> int:
-        return len(self.all)
-
-    # Smartplugs
-    def get_by_id(self, id: int):
-        """
-        Gets a schedule object from the schedules id
-        param id: id of schedule
-        return: _WiserSchedule object
-        """
-        #try:
-        return [schedule for schedule in self.all if schedule.id == id][0]
-        #except IndexError:
-        #    return None
-       
-
-    def get_by_name(self, name: str):
-        """
-        Gets a schedule object from the schedules name
-        (room name, smart plug name, hotwater)
-        param name: name of schedule
-        return: _WiserSchedule object
-        """
-        try:
-            return [schedule for schedule in self.all if schedule.name == name][0]
-        except IndexError:
-            return None
-
 class _WiserSchedule(object):
     """Class representing a wiser Schedule"""
 
@@ -205,7 +158,7 @@ class _WiserSchedule(object):
                 schedule_data,
             )
             if result:
-                _LOGGER.info(
+                _LOGGER.debug(
                     "Wiser schedule - {} command successful".format(
                         inspect.stack()[1].function
                     )
@@ -258,7 +211,6 @@ class _WiserSchedule(object):
         param toId: id of schedule to copy to
         return: boolen - true = successfully set, false = failed to set
         """
-        #TODO Remove name field from schedule!!!  Causing name issue when copying!!!
         return self._send_schedule(self._remove_schedule_elements(self._schedule_data), to_id)
 
     def save_schedule_to_file(self, schedule_file: str) -> bool:
@@ -272,7 +224,7 @@ class _WiserSchedule(object):
                 json.dump(self._schedule_data, file, indent=4)
             return True
         except Exception as ex:
-            _LOGGER.debug(ex)
+            _LOGGER.error(f"Error saving schedule to file: {ex}")
             return False
 
     def save_schedule_to_yaml_file(self, schedule_yaml_file: str) -> bool:
@@ -287,7 +239,7 @@ class _WiserSchedule(object):
                 yaml.dump(self._convert_from_wiser_schedule(self._schedule_data), file)
             return True
         except Exception as ex:
-            _LOGGER.debug(ex)
+            _LOGGER.error(f"Error saving schedule to yaml file: {ex}")
             return False
 
     def set_schedule(self, schedule_data: dict) -> bool:
@@ -312,7 +264,7 @@ class _WiserSchedule(object):
             _LOGGER.error(f"Error setting schedule from file: {ex}")
             return False
 
-    def set_schedule_from_yaml_file(self, schedule_file: str) -> bool:
+    def set_schedule_from_yaml_file(self, schedule_yaml_file: str) -> bool:
         """
         Set schedule from file.
         param schedule_file: file of yaml data respresenting a schedule
@@ -320,7 +272,7 @@ class _WiserSchedule(object):
         """
         try:
             yaml = YAML()
-            with open(schedule_file, "r") as file:
+            with open(schedule_yaml_file, "r") as file:
                 y = yaml.load(file)
                 s = self._convert_to_wiser_schedule(y)
                 self.set_schedule(s)
@@ -329,6 +281,7 @@ class _WiserSchedule(object):
             _LOGGER.error(f"Error setting schedule from yaml file: {ex}")
             return False
 
+
 class _WiserScheduleNext:
     """Data structure for schedule next entry data"""
 
@@ -355,3 +308,49 @@ class _WiserScheduleNext:
         if self._schedule_type == TEXT_ONOFF:
             return self._data.get("State")
         return None
+
+
+class _WiserScheduleCollection(object):
+    """Class holding all wiser schedule objects"""
+
+    def __init__(self, wiser_rest_controller, schedule_data: dict):
+        self._wiser_rest_controller = wiser_rest_controller
+        self._schedules = []
+
+        self._build(schedule_data)
+
+    def _build(self, schedule_data):
+        for schedule_type in schedule_data:
+            for schedule in schedule_data.get(schedule_type):
+                self._schedules.append(_WiserSchedule(self._wiser_rest_controller, schedule_type, schedule))
+
+    @property
+    def all(self) -> list:
+        return self._schedules
+
+    @property
+    def count(self) -> int:
+        return len(self.all)
+
+    def get_by_id(self, id: int) -> _WiserSchedule | None:
+        """
+        Gets a schedule object from the schedules id
+        param id: id of schedule
+        return: _WiserSchedule object
+        """
+        try:
+            return [schedule for schedule in self.all if schedule.id == id][0]
+        except IndexError:
+            return None
+
+    def get_by_name(self, name: str) -> _WiserSchedule | None:
+        """
+        Gets a schedule object from the schedules name
+        (room name, smart plug name, hotwater)
+        param name: name of schedule
+        return: _WiserSchedule object
+        """
+        try:
+            return [schedule for schedule in self.all if schedule.name == name][0]
+        except IndexError:
+            return None
